This class of objects is returned by the isurvfit class of functions
to represent a IDP survival curve.
Objects of this class have methods for the functions print,
plot.
total number of subjects in each curve.
the time points at which the curve has a step.
the number of subjects at risk at t.
the number of events that occur at time t.
the number of subjects who exit the risk set, without an event, at time t. (This number can be computed from the successive values of the number at risk).
the estimate of upper expectation of the survival probability at time t+0.
the estimate of lower expectation of the survival probability at time t+0.
the estimate of lower expectation of the survival probability at time t=0. The upper expectation is always 1.
the standard deviation of the upper distribution of the survival probability.
the standard deviation of the lower distribution of the survival probability.
upper confidence limit for the survival curve.
lower confidence limit for the survival curve.
lower confidence limit for the survival curve at t=0. The upper is always 1.
the approximation used to compute the confidence limits.
the level of the confidence limits, e.g. 90 or 95%.
number of elements of the time vector
corresponding to each curve.
The names of the elements are labels for the curves.
an image of the call that produced the object.
isurvfit
plot.isurvfit