Learn R Programming

IDPSurvival (version 1.1)

isurvfit.object: IDP Survival Curve Object

Description

This class of objects is returned by the isurvfit class of functions to represent a IDP survival curve.

Objects of this class have methods for the functions print, plot.

Arguments

n
total number of subjects in each curve.
time
the time points at which the curve has a step.
n.risk
the number of subjects at risk at t.
n.event
the number of events that occur at time t.
n.censor
the number of subjects who exit the risk set, without an event, at time t. (This number can be computed from the successive values of the number at risk).
survUP
the estimate of upper expectation of the survival probability at time t+0.
survLOW
the estimate of lower expectation of the survival probability at time t+0.
survLOW0
the estimate of lower expectation of the survival probability at time t=0. The upper expectation is always 1.
std.up
the standard deviation of the upper distribution of the survival probability.
std.low
the standard deviation of the lower distribution of the survival probability.
upper
upper confidence limit for the survival curve.
lower
lower confidence limit for the survival curve.
lower0
lower confidence limit for the survival curve at t=0. The upper is always 1.
conf.type
the approximation used to compute the confidence limits.
conf.int
the level of the confidence limits, e.g. 90 or 95%.
strata
number of elements of the time vector corresponding to each curve. The names of the elements are labels for the curves.
call
an image of the call that produced the object.

See Also

isurvfit plot.isurvfit